#!/bin/bash

# http://www.elinux.org/Runtime_Memory_Measurement#.2Fproc.2F.3Cpid.3E.2Fstatm

JAVA_HOME=/opt/java-oracle/jdk1.7
FILE=jvm-mem.txt
LINE="================================================================="

if [ -n "$1" ]
then
	MPID=$1
else
	MPID=$(ps -o pid --no-headers -U cdm)
	MPID=$(echo $MPID) # trim whitespace!
fi

if [ -z "$MPID" ]
then
 echo "MPID missing"
 exit -1
fi


echo $LINE
echo "ps:" $(ps -p $MPID  -o rssize) 
echo $LINE
$JAVA_HOME/bin/jmap -J-d64 -heap $MPID | ./awk-jmap-heap-analyse
echo $LINE
echo "ps:" $(ps -p $MPID  -o rssize)
echo $LINE
# Note on pmap from slashdot, cited on 
# http://www.elinux.org/Runtime_Memory_Measurement#.2Fproc.2F.3Cpid.3E.2Fstatm
#
# pmap *also* overestimates memory usage, because some portion of the mapped address
# space isn't actually in use. RSS, on the other hand, only measures memory that is
# actually in use, but doesn't distinguish between memory that is shared and memory
# that is not. VSZ is the most pessimistic measure, since it includes all mapped
# memory, shared and unshared.
pmap -xp $MPID | ./awk-pmap-analyse | sort -n -r 
echo $LINE
echo "ps:" $(ps -p $MPID  -o rssize)
echo $LINE
# http://unix.stackexchange.com/questions/34795/correctly-determining-memory-usage-in-linux
cat /proc/$MPID/status

